==> gulp-tarima-0.2.0.tgz: package/lib/index.js <==
'use strict';

var PLUGIN_NAME = 'gulp-tarima';

var through2 = require('through2'),
    gutil = require('gulp-util'),
    path = require('path');

var File = gutil.File,
    PluginError = gutil.PluginError;

module.exports = function(options, callback) {
  var tarima = require('tarima');

  if (typeof options === 'string') {
    options = {
      filename: options
    };
  }

  options = options || {};

  options.wrapper = callback || options.wrapper || function(code) {
    return code + '\nmodule.exports = JST;';
  };

  var files = [];

  function write(file, enc, cb) {
    if (file.isStream()) {
      return cb(new PluginError(PLUGIN_NAME, 'Streaming not supported'));
    }

    var partial = tarima.parse(file.path, file.contents.toString(), options);

    if (file.isBuffer()) {
      var data = options.locals || options.data || file.data;

      file.path = path.join(path.dirname(file.path), partial.params.name + '.' + partial.params.ext);
      file.keypath = partial.params.keypath;

      var code = partial.compile(data);

      if (!options.filename && partial.params.ext === 'js' && code.indexOf('module.exports') === -1) {
        code = 'module.exports = ' + code + ';';
      }

      file.contents = new Buffer(code);
    }

    if (options.filename && file.path.indexOf('.js') > -1) {
      files.push(partial);
      cb(null);
    } else {
      cb(null, file);
    }
  }

  function end(cb) {
    if (options.filename) {
      var code = tarima.bundle(files, options);

      this.push(new File({
        path: options.filename,
        contents: new Buffer(code)
      }));

      cb(null);
    }
  }

  return through2.obj(write, end);
};

==> gulp-tarima-0.3.1.tgz: package/lib/index.js <==
'use strict';

var PLUGIN_NAME = 'gulp-tarima';

var through2 = require('through2'),
    gutil = require('gulp-util'),
    path = require('path');

var File = gutil.File,
    PluginError = gutil.PluginError;

var tarima = require('tarima');

module.exports = function(options, callback) {
  if (typeof options === 'string') {
    options = {
      filename: options
    };
  }

  options = options || {};

  options.wrapper = callback || options.wrapper || function(code) {
    return code + '\nmodule.exports = JST;';
  };

  var files = [];

  function write(file, enc, cb) {
    if (file.isStream()) {
      return cb(new PluginError(PLUGIN_NAME, 'Streaming not supported'));
    }

    var partial = tarima.parse(file.path, file.contents.toString(), options);

    if (file.isBuffer()) {
      var data = options.locals || options.data || file.data;

      file.path = path.join(path.dirname(file.path), partial.params.name + '.' + partial.params.ext);
      file.keypath = partial.params.keypath;

      var code = partial.compile(data);

      var undef = code.indexOf('module.exports') === -1 && /^\s*function/.test(code);

      if (!options.filename && partial.params.ext === 'js' && undef) {
        code = 'module.exports = ' + code + ';';
      }

      file.contents = new Buffer(code);
    }

    if (options.filename && file.path.indexOf('.js') > -1) {
      files.push(partial);
      cb(null);
    } else {
      cb(null, file);
    }
  }

  function end(cb) {
    if (options.filename) {
      var code = tarima.bundle(files, options);

      this.push(new File({
        path: options.filename,
        contents: new Buffer(code)
      }));

      cb(null);
    } else {
      cb();
    }
  }

  return through2.obj(write, end);
};

// expose tarima api
for (var key in tarima) {
  if (Object.prototype.hasOwnProperty.call(tarima, key)) {
    module.exports[key] = tarima[key];
  }
}
